# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`cvmfs`](#cvmfs): Installs and Configures CvmFS
* [`cvmfs::fsck`](#cvmfsfsck): enable check_fsck as a cron or systemd timer

#### Private Classes

* `cvmfs::apt`: Configure cvmfs apt repositories
* `cvmfs::config`: Central configuration of CvmFS
* `cvmfs::install`: Install cvmfs from a yum repository.
* `cvmfs::service`: Manages the cvmfs services. Opionally this also manages the autofs services
* `cvmfs::yum`: Configure cvmfs yum repositories

### Defined types

* [`cvmfs::domain`](#cvmfsdomain): Configure a a domain of cvmfs repositories
* [`cvmfs::id_map`](#cvmfsid_map): Create a map file uid or gid mappings
* [`cvmfs::mount`](#cvmfsmount): Mount one cvmfs repository. Most parameters map as lower case
versions of the raw cvmfs parameters.

## Classes

### <a name="cvmfs"></a>`cvmfs`

Deprecated paramters below

* **See also**
  * https://cvmfs.readthedocs.io/en/stable/apx-parameters.html
    * CVMFS configuration parameters

#### Examples

##### Simple Example For one Mount

```puppet
class{'cvmfs':
  cvmfs_http_proxy => 'http://ca-proxy.example.org:3128',
  cvmfs_quota_limit => 100
}
cvmfs::mount{'files.example.org:
  cvmfs_server_url => 'http://web.example.org/cvmfs/files.example.org',
}
```

##### Mount a Domain

```puppet
class{'cvmfs':
  cvmfs_http_proxy  => 'http://ca-proxy.example.org:3128',
  cvmfs_quota_limit => 100,
}
cvmfs::domain{'example.net'
  cvmfs_server_url => 'http://web.example.org/cvmfs/@fqrn@'
}
```

##### Use Mount rather than AutoFS

```puppet
class{'cvmfs':
  mount_method => 'mount',
}
```

##### Specify mounts as a hash

```puppet
class{'cvmfs':
  cvmfs_hash => {
    'foo.example.org' => { 'cvmfs_server_url => 'http://web.example.org/cmfs/foo.example.org' },
    'bar.example.org' => { 'cvmfs_server_url => 'http://web.example.org/cvmfs/bar.example.org' },
  }
}
```

#### Parameters

The following parameters are available in the `cvmfs` class:

* [`mount_method`](#mount_method)
* [`manage_autofs_service`](#manage_autofs_service)
* [`cvmfs_quota_limit`](#cvmfs_quota_limit)
* [`cvmfs_quota_ratio`](#cvmfs_quota_ratio)
* [`cvmfs_http_proxy`](#cvmfs_http_proxy)
* [`cvmfs_cache_base`](#cvmfs_cache_base)
* [`cvmfs_ipfamily_prefer`](#cvmfs_ipfamily_prefer)
* [`cvmfs_dns_min_ttl`](#cvmfs_dns_min_ttl)
* [`cvmfs_dns_max_ttl`](#cvmfs_dns_max_ttl)
* [`cvmfs_claim_ownership`](#cvmfs_claim_ownership)
* [`cvmfs_uid_map`](#cvmfs_uid_map)
* [`cvmfs_gid_map`](#cvmfs_gid_map)
* [`cvmfs_memcache_size`](#cvmfs_memcache_size)
* [`cvmfs_mount_rw`](#cvmfs_mount_rw)
* [`cvmfs_follow_redirects`](#cvmfs_follow_redirects)
* [`cvmfs_timeout`](#cvmfs_timeout)
* [`cvmfs_timeout_direct`](#cvmfs_timeout_direct)
* [`cvmfs_nfiles`](#cvmfs_nfiles)
* [`cvmfs_syslog_level`](#cvmfs_syslog_level)
* [`cvmfs_tracefile`](#cvmfs_tracefile)
* [`cvmfs_debuglog`](#cvmfs_debuglog)
* [`cvmfs_max_ttl`](#cvmfs_max_ttl)
* [`cvmfs_version`](#cvmfs_version)
* [`repo_base`](#repo_base)
* [`repo_includepkgs`](#repo_includepkgs)
* [`repo_priority`](#repo_priority)
* [`repo_proxy`](#repo_proxy)
* [`repo_config_enabled`](#repo_config_enabled)
* [`repo_testing_enabled`](#repo_testing_enabled)
* [`repo_gpgcheck`](#repo_gpgcheck)
* [`repo_gpgkey`](#repo_gpgkey)
* [`repo_manage`](#repo_manage)
* [`cvmfs_use_geoapi`](#cvmfs_use_geoapi)
* [`cvmfs_repositories`](#cvmfs_repositories)
* [`cvmfs_hash`](#cvmfs_hash)
* [`cvmfs_env_variables`](#cvmfs_env_variables)
* [`default_cvmfs_partsize`](#default_cvmfs_partsize)
* [`cvmfs_domain_hash`](#cvmfs_domain_hash)
* [`cvmfs_instrument_fuse`](#cvmfs_instrument_fuse)
* [`cvmfs_repo_list`](#cvmfs_repo_list)
* [`cvmfs_alien_cache`](#cvmfs_alien_cache)
* [`cvmfs_shared_cache`](#cvmfs_shared_cache)
* [`cvmfs_yum`](#cvmfs_yum)
* [`cvmfs_yum_priority`](#cvmfs_yum_priority)
* [`cvmfs_yum_proxy`](#cvmfs_yum_proxy)
* [`cvmfs_yum_config`](#cvmfs_yum_config)
* [`cvmfs_yum_config_enabled`](#cvmfs_yum_config_enabled)
* [`cvmfs_yum_testing`](#cvmfs_yum_testing)
* [`cvmfs_yum_testing_enabled`](#cvmfs_yum_testing_enabled)
* [`cvmfs_yum_gpgcheck`](#cvmfs_yum_gpgcheck)
* [`cvmfs_yum_gpgkey`](#cvmfs_yum_gpgkey)
* [`cvmfs_yum_manage_repo`](#cvmfs_yum_manage_repo)
* [`cvmfs_yum_includepkgs`](#cvmfs_yum_includepkgs)

##### <a name="mount_method"></a>`mount_method`

Data type: `Enum['autofs','mount','none']`

The `autofs` option will configure cvmfs to be mounted with autofs. The `mount` option will
use puppet's mount type, currently adding a line to /etc/fstab. The *none* option
skips all mounting.  Note that migrating between for instance *autofs* and then *mount* is not supported.

Default value: `'autofs'`

##### <a name="manage_autofs_service"></a>`manage_autofs_service`

Data type: `Boolean`

should the autofs service be maintained.

Default value: ``true``

##### <a name="cvmfs_quota_limit"></a>`cvmfs_quota_limit`

Data type: `Variant[Enum['auto'],Integer]`

The cvmfs quota size in megabytes.

Default value: `1000`

##### <a name="cvmfs_quota_ratio"></a>`cvmfs_quota_ratio`

Data type: `Float`

If set , e.g '0.8', then 0.8 of the partition size
the cvmfs cache is on will be used. Setting this assumes you have
pre-allocated a partition to the cvmfs cache or else it makes little sense.

Default value: `0.85`

##### <a name="cvmfs_http_proxy"></a>`cvmfs_http_proxy`

Data type: `Variant[Undef,String]`

List of squid servers, e.g `http://squid1.example.org;http;//squid2.example.org`

##### <a name="cvmfs_cache_base"></a>`cvmfs_cache_base`

Data type: `Stdlib::Absolutepath`

Location of the CVMFS cache base

Default value: `'/var/lib/cvmfs'`

##### <a name="cvmfs_ipfamily_prefer"></a>`cvmfs_ipfamily_prefer`

Data type: `Optional[Variant[Integer[4,4],Integer[6,6]]]`

Preferred IP protocol for dual-stack proxies. If not set, cvmfs default will be used.

Default value: ``undef``

##### <a name="cvmfs_dns_min_ttl"></a>`cvmfs_dns_min_ttl`

Data type: `Optional[Integer]`

Minimum ttl of DNS lookups in seconds.

Default value: ``undef``

##### <a name="cvmfs_dns_max_ttl"></a>`cvmfs_dns_max_ttl`

Data type: `Optional[Integer]`

Maximum ttl of DNS lookups in seconds.

Default value: ``undef``

##### <a name="cvmfs_claim_ownership"></a>`cvmfs_claim_ownership`

Data type: `Optional[Enum['yes','no']]`

Whether the client claims ownership of files or not.

Default value: ``undef``

##### <a name="cvmfs_uid_map"></a>`cvmfs_uid_map`

Data type: `Optional[Hash[Variant[Integer,String], Integer, 1]]`

Hash of UID pairs to map UIDs from catalogue to on the client.

Default value: ``undef``

##### <a name="cvmfs_gid_map"></a>`cvmfs_gid_map`

Data type: `Optional[Hash[Variant[Integer,String], Integer, 1]]`

Hash of GID pairs to map GIDs from catalogue to on the client.

Default value: ``undef``

##### <a name="cvmfs_memcache_size"></a>`cvmfs_memcache_size`

Data type: `Optional[Integer]`

Size of the CernVM-FS meta-data memory cache in Megabyte.

Default value: ``undef``

##### <a name="cvmfs_mount_rw"></a>`cvmfs_mount_rw`

Data type: `Optional[Enum['yes','no']]`

Mount option to mount as read-only or read/write.

Default value: ``undef``

##### <a name="cvmfs_follow_redirects"></a>`cvmfs_follow_redirects`

Data type: `Optional[Enum['yes','no']]`

Sets CVMFS_FOLLOW_REDIRECTS to its value

Default value: ``undef``

##### <a name="cvmfs_timeout"></a>`cvmfs_timeout`

Data type: `Optional[Integer]`

cvmfs timeout setting.

Default value: ``undef``

##### <a name="cvmfs_timeout_direct"></a>`cvmfs_timeout_direct`

Data type: `Optional[Integer]`

cvmfs timeout to direct connections.

Default value: ``undef``

##### <a name="cvmfs_nfiles"></a>`cvmfs_nfiles`

Data type: `Optional[Integer]`

Number of open files, system setting.

Default value: ``undef``

##### <a name="cvmfs_syslog_level"></a>`cvmfs_syslog_level`

Data type: `Optional[Integer[1,2]]`

Level to syslog at.

Default value: ``undef``

##### <a name="cvmfs_tracefile"></a>`cvmfs_tracefile`

Data type: `Optional[Stdlib::Absolutepath]`

Create a tracefile at this location.

Default value: ``undef``

##### <a name="cvmfs_debuglog"></a>`cvmfs_debuglog`

Data type: `Optional[Stdlib::Absolutepath]`

Create a debug log file at this location.

Default value: ``undef``

##### <a name="cvmfs_max_ttl"></a>`cvmfs_max_ttl`

Data type: `Optional[Integer]`

Max ttl.

Default value: ``undef``

##### <a name="cvmfs_version"></a>`cvmfs_version`

Data type: `String[1]`

Version of cvmfs to install.

Default value: `'present'`

##### <a name="repo_base"></a>`repo_base`

Data type: `Stdlib::Httpurl`

URL containting stable, testing and config apt or yum repositories. Default in hiera data.

##### <a name="repo_includepkgs"></a>`repo_includepkgs`

Data type: `Optional[Variant[Enum['absent'], Array[String[1]]]]`

Specify an includepkgs to the yum repos to ignore other packages.

##### <a name="repo_priority"></a>`repo_priority`

Data type: `Integer`

Yum priority of repositories

Default value: `80`

##### <a name="repo_proxy"></a>`repo_proxy`

Data type: `Optional[Stdlib::Httpurl]`

http proxy for cvmfs yum package repository

Default value: ``undef``

##### <a name="repo_config_enabled"></a>`repo_config_enabled`

Data type: `Boolean`

Should the config yum repository be enabled

Default value: ``false``

##### <a name="repo_testing_enabled"></a>`repo_testing_enabled`

Data type: `Boolean`

Should the testing repository be enabled.

Default value: ``false``

##### <a name="repo_gpgcheck"></a>`repo_gpgcheck`

Data type: `Boolean`

set to false to disable GPG checking

Default value: ``true``

##### <a name="repo_gpgkey"></a>`repo_gpgkey`

Data type: `Stdlib::Httpurl`

Set a custom GPG key for yum repos. Default in hiera data.

##### <a name="repo_manage"></a>`repo_manage`

Data type: `Boolean`

Set to false to disable yum or apt repositories management.

Default value: ``true``

##### <a name="cvmfs_use_geoapi"></a>`cvmfs_use_geoapi`

Data type: `Optional[Enum['yes','no']]`

Enable geoapi to find suitable proxies.

Default value: ``undef``

##### <a name="cvmfs_repositories"></a>`cvmfs_repositories`

Data type: `Optional[String[1]]`

If undef `CVMFS_REPOSITORIES` in `default.local` will be populated
automatically from what is explicitly mounted with `cvmfs::mount`. If this is
specified then`CVMFS_REPOSITORIES` list in `default.local` will be exactly managed with this variable.
e.g `cvmfs-config.cern.ch,atlas.cern.ch`

Default value: ``undef``

##### <a name="cvmfs_hash"></a>`cvmfs_hash`

Data type: `Hash`

Rather than using cvmfs::mount defined type a hash of mounts can be sepecfied.

Default value: `{}`

##### <a name="cvmfs_env_variables"></a>`cvmfs_env_variables`

Data type: `Hash`

`$cvmfs_env_variables = {'CMS_LOCAL_SITE' => '<path to siteconf>'`
 will produce `export CMS_LOCAL_SITE=<path to siteconf>`in the default.local file.

Default value: `{}`

##### <a name="default_cvmfs_partsize"></a>`default_cvmfs_partsize`

Data type: `Integer`



Default value: `10000`

##### <a name="cvmfs_domain_hash"></a>`cvmfs_domain_hash`

Data type: `Hash`

Specify of a hash `cvmfs::domain` types.

Default value: `{}`

##### <a name="cvmfs_instrument_fuse"></a>`cvmfs_instrument_fuse`

Data type: `Boolean`

Instrument Fuse

Default value: ``false``

##### <a name="cvmfs_repo_list"></a>`cvmfs_repo_list`

Data type: `Boolean`

Specify exactly the REPO_LIST in `defaults.local` overriding auto population.

Default value: ``true``

##### <a name="cvmfs_alien_cache"></a>`cvmfs_alien_cache`

Data type: `Optional[String]`

Use an alien cache

Default value: ``undef``

##### <a name="cvmfs_shared_cache"></a>`cvmfs_shared_cache`

Data type: `Optional[Enum['yes','no']]`

Enable a shared cache

Default value: ``undef``

##### <a name="cvmfs_yum"></a>`cvmfs_yum`

Data type: `Optional[Stdlib::Httpurl]`

Deprecated, use repo_base

Default value: ``undef``

##### <a name="cvmfs_yum_priority"></a>`cvmfs_yum_priority`

Data type: `Optional[Integer]`

Deprecated, use repo_priority

Default value: ``undef``

##### <a name="cvmfs_yum_proxy"></a>`cvmfs_yum_proxy`

Data type: `Optional[Stdlib::Httpurl]`

Deprecated, user repo_proxy

Default value: ``undef``

##### <a name="cvmfs_yum_config"></a>`cvmfs_yum_config`

Data type: `Optional[Stdlib::Httpurl]`

Deprecated, use repo_base

Default value: ``undef``

##### <a name="cvmfs_yum_config_enabled"></a>`cvmfs_yum_config_enabled`

Data type: `Optional[Integer[0,1]]`

Deprecated, user repo_config_enabled

Default value: ``undef``

##### <a name="cvmfs_yum_testing"></a>`cvmfs_yum_testing`

Data type: `Optional[Stdlib::Httpurl]`

Deprecated, use repo_base

Default value: ``undef``

##### <a name="cvmfs_yum_testing_enabled"></a>`cvmfs_yum_testing_enabled`

Data type: `Optional[Integer[0,1]]`

Deprecated, use repo_testing_enabled

Default value: ``undef``

##### <a name="cvmfs_yum_gpgcheck"></a>`cvmfs_yum_gpgcheck`

Data type: `Optional[Integer[0,1]]`

Deprecated, use repo_gpgcheck

Default value: ``undef``

##### <a name="cvmfs_yum_gpgkey"></a>`cvmfs_yum_gpgkey`

Data type: `Optional[Variant[Stdlib::Filesource,Stdlib::Httpurl]]`

Deprecated, use repo_gpgkey

Default value: ``undef``

##### <a name="cvmfs_yum_manage_repo"></a>`cvmfs_yum_manage_repo`

Data type: `Optional[Boolean]`

Deprecated, use repo_manage

Default value: ``undef``

##### <a name="cvmfs_yum_includepkgs"></a>`cvmfs_yum_includepkgs`

Data type: `Optional[Variant[Enum['absent'], Array[String]]]`

Deprecated, use repo_includepkgs

Default value: ``undef``

### <a name="cvmfsfsck"></a>`cvmfs::fsck`

#

#### Parameters

The following parameters are available in the `cvmfs::fsck` class:

* [`cvmfs_cache_base`](#cvmfs_cache_base)
* [`options`](#options)
* [`onreboot`](#onreboot)
* [`usesystemd`](#usesystemd)

##### <a name="cvmfs_cache_base"></a>`cvmfs_cache_base`

Data type: `Any`

Root of cvmfs ache

Default value: `$cvmfs::cvmfs_cache_base`

##### <a name="options"></a>`options`

Data type: `Any`

Any extra options

Default value: `''`

##### <a name="onreboot"></a>`onreboot`

Data type: `Any`

Should fsck be run after every reboot

Default value: ``false``

##### <a name="usesystemd"></a>`usesystemd`

Data type: `Optional[Boolean]`

Use a systemd timer

Default value: ``undef``

## Defined types

### <a name="cvmfsdomain"></a>`cvmfs::domain`

Configure a a domain of cvmfs repositories

#### Examples

##### Add the example.org domain

```puppet
cvmfs::domain{'example.org':
  cvmfs_server_url = 'http://example.org/cvmfs/@fqrn@',
}
```

#### Parameters

The following parameters are available in the `cvmfs::domain` defined type:

* [`domain`](#domain)
* [`cvmfs_quota_limit`](#cvmfs_quota_limit)
* [`cvmfs_server_url`](#cvmfs_server_url)
* [`cvmfs_http_proxy`](#cvmfs_http_proxy)
* [`cvmfs_timeout`](#cvmfs_timeout)
* [`cvmfs_timeout_direct`](#cvmfs_timeout_direct)
* [`cvmfs_nfiles`](#cvmfs_nfiles)
* [`cvmfs_max_ttl`](#cvmfs_max_ttl)
* [`cvmfs_env_variables`](#cvmfs_env_variables)
* [`cvmfs_use_geoapi`](#cvmfs_use_geoapi)
* [`cvmfs_follow_redirects`](#cvmfs_follow_redirects)
* [`cvmfs_external_fallback_proxy`](#cvmfs_external_fallback_proxy)
* [`cvmfs_external_http_proxy`](#cvmfs_external_http_proxy)
* [`cvmfs_external_timeout`](#cvmfs_external_timeout)
* [`cvmfs_external_timeout_direct`](#cvmfs_external_timeout_direct)
* [`cvmfs_external_url`](#cvmfs_external_url)
* [`cvmfs_public_key`](#cvmfs_public_key)
* [`cvmfs_keys_dir`](#cvmfs_keys_dir)

##### <a name="domain"></a>`domain`

Data type: `Stdlib::Fqdn`

The domain of CvmFS repositories to mount

Default value: `$name`

##### <a name="cvmfs_quota_limit"></a>`cvmfs_quota_limit`

Data type: `Optional[Integer]`

Per mount quota limit, not relavent to shared cache. Sets cvmfs_quota_limit

Default value: ``undef``

##### <a name="cvmfs_server_url"></a>`cvmfs_server_url`

Data type: `Optional[String[1]]`

Stratum 1 list, typically `;` delimited. Sets CVMFS_SERVER_URL parameter.

Default value: ``undef``

##### <a name="cvmfs_http_proxy"></a>`cvmfs_http_proxy`

Data type: `Optional[String[1]]`

List of http proxies to use. Sets CVMFS_PROXY_LIST parameter.

Default value: ``undef``

##### <a name="cvmfs_timeout"></a>`cvmfs_timeout`

Data type: `Optional[Integer]`

Sets CVMFS_HTTP_TIMEOUT parameter

Default value: ``undef``

##### <a name="cvmfs_timeout_direct"></a>`cvmfs_timeout_direct`

Data type: `Optional[Integer]`

Sets CVMFS_HTTP_TIMEOUT_DIRECT

Default value: ``undef``

##### <a name="cvmfs_nfiles"></a>`cvmfs_nfiles`

Data type: `Optional[Integer]`

Number of open files permitted on the OS. Sets CVMFS_NFILES

Default value: ``undef``

##### <a name="cvmfs_max_ttl"></a>`cvmfs_max_ttl`

Data type: `Optional[Integer]`

Maximum effective TTL in seconds for DNS queries of proxy server names. Sets CVMFS_MAX_TTL

Default value: ``undef``

##### <a name="cvmfs_env_variables"></a>`cvmfs_env_variables`

Data type: `Optional[Hash]`

Sets per repo environments variables for magic links.

Default value: ``undef``

##### <a name="cvmfs_use_geoapi"></a>`cvmfs_use_geoapi`

Data type: `Optional[Stdlib::Yes_no]`

Set CVMFS_MAX_GEOAPI

Default value: ``undef``

##### <a name="cvmfs_follow_redirects"></a>`cvmfs_follow_redirects`

Data type: `Optional[Stdlib::Yes_no]`

Sets CVMFS_FOLLOW_REDIRECTS.

Default value: ``undef``

##### <a name="cvmfs_external_fallback_proxy"></a>`cvmfs_external_fallback_proxy`

Data type: `Optional[String]`

Sets CVMFS_EXTERNAL_FALLBACK_PROXY

Default value: ``undef``

##### <a name="cvmfs_external_http_proxy"></a>`cvmfs_external_http_proxy`

Data type: `Optional[String]`

Sets CVMFS_EXTERNAL_HTTP_PROXY

Default value: ``undef``

##### <a name="cvmfs_external_timeout"></a>`cvmfs_external_timeout`

Data type: `Optional[Integer]`

Sets CVMFS_EXTERNAL_TIMEOUT

Default value: ``undef``

##### <a name="cvmfs_external_timeout_direct"></a>`cvmfs_external_timeout_direct`

Data type: `Optional[Integer]`

Sets CVMFS_EXTERNAL_TIMEOUT_DIRECT

Default value: ``undef``

##### <a name="cvmfs_external_url"></a>`cvmfs_external_url`

Data type: `Optional[String]`

Sets CVMFS_EXTERNAL_URL

Default value: ``undef``

##### <a name="cvmfs_public_key"></a>`cvmfs_public_key`

Data type: `Optional[String[1]]`

Specify repository signing key

Default value: ``undef``

##### <a name="cvmfs_keys_dir"></a>`cvmfs_keys_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Specify repository directory with signing keys

Default value: ``undef``

### <a name="cvmfsid_map"></a>`cvmfs::id_map`

Create a map file uid or gid mappings

#### Parameters

The following parameters are available in the `cvmfs::id_map` defined type:

* [`map`](#map)
* [`location`](#location)

##### <a name="map"></a>`map`

Data type: `Hash[Variant[Integer,String], Integer, 1]`

Hash of `{from => to}` pairs

##### <a name="location"></a>`location`

Data type: `Stdlib::Absolutepath`

Path to write map to.

Default value: `$title`

### <a name="cvmfsmount"></a>`cvmfs::mount`

Mount one cvmfs repository. Most parameters map as lower case
versions of the raw cvmfs parameters.

* **See also**
  * https://cvmfs.readthedocs.io/en/stable/apx-parameters.html
    * CVMFS configuration parameters

#### Examples

##### Trivial Mount

```puppet
cvmfs::mount{'files.example.org:
  cvmfs_server_url => 'http://web.exampple.org/cvmfs/files.example.org',
}
```

##### Mount with Environment Variables.

```puppet
cvmfs::mount{'foobar.example.org':
  cvmfs_env_variables => {
    'FOOT' => 'ball',
    'GOLF' => 'club',
  }
}
```

#### Parameters

The following parameters are available in the `cvmfs::mount` defined type:

* [`repo`](#repo)
* [`cvmfs_quota_limit`](#cvmfs_quota_limit)
* [`cvmfs_server_url`](#cvmfs_server_url)
* [`cvmfs_http_proxy`](#cvmfs_http_proxy)
* [`cvmfs_timeout`](#cvmfs_timeout)
* [`cvmfs_timeout_direct`](#cvmfs_timeout_direct)
* [`cvmfs_nfiles`](#cvmfs_nfiles)
* [`cvmfs_public_key`](#cvmfs_public_key)
* [`cvmfs_keys_dir`](#cvmfs_keys_dir)
* [`cvmfs_max_ttl`](#cvmfs_max_ttl)
* [`cvmfs_env_variables`](#cvmfs_env_variables)
* [`cvmfs_use_geoapi`](#cvmfs_use_geoapi)
* [`mount_method`](#mount_method)
* [`cvmfs_repo_list`](#cvmfs_repo_list)
* [`cvmfs_mount_rw`](#cvmfs_mount_rw)
* [`cvmfs_memcache_size`](#cvmfs_memcache_size)
* [`cvmfs_claim_ownership`](#cvmfs_claim_ownership)
* [`cvmfs_uid_map`](#cvmfs_uid_map)
* [`cvmfs_gid_map`](#cvmfs_gid_map)
* [`cvmfs_follow_redirects`](#cvmfs_follow_redirects)
* [`cvmfs_external_fallback_proxy`](#cvmfs_external_fallback_proxy)
* [`cvmfs_external_http_proxy`](#cvmfs_external_http_proxy)
* [`cvmfs_external_timeout`](#cvmfs_external_timeout)
* [`cvmfs_external_timeout_direct`](#cvmfs_external_timeout_direct)
* [`cvmfs_external_url`](#cvmfs_external_url)
* [`cvmfs_repository_tag`](#cvmfs_repository_tag)
* [`mount_options`](#mount_options)

##### <a name="repo"></a>`repo`

Data type: `Stdlib::Fqdn`

The fully qualified repository name to mount

Default value: `$name`

##### <a name="cvmfs_quota_limit"></a>`cvmfs_quota_limit`

Data type: `Optional[Integer]`

Per mount quota limit, not relavent to shared cache. Sets cvmfs_quota_limit

Default value: ``undef``

##### <a name="cvmfs_server_url"></a>`cvmfs_server_url`

Data type: `Optional[String[1]]`

Stratum 1 list, typically `;` delimited. Sets CVMFS_SERVER_URL parameter.

Default value: ``undef``

##### <a name="cvmfs_http_proxy"></a>`cvmfs_http_proxy`

Data type: `Optional[String[1]]`

List of http proxies to use. Sets CVMFS_PROXY_LIST parameter.

Default value: ``undef``

##### <a name="cvmfs_timeout"></a>`cvmfs_timeout`

Data type: `Optional[Integer]`

Sets CVMFS_HTTP_TIMEOUT parameter

Default value: ``undef``

##### <a name="cvmfs_timeout_direct"></a>`cvmfs_timeout_direct`

Data type: `Optional[Integer]`

Sets CVMFS_HTTP_TIMEOUT_DIRECT

Default value: ``undef``

##### <a name="cvmfs_nfiles"></a>`cvmfs_nfiles`

Data type: `Optional[Integer]`

Number of open files permitted on the OS. Sets CVMFS_NFILES

Default value: ``undef``

##### <a name="cvmfs_public_key"></a>`cvmfs_public_key`

Data type: `Optional[String[1]]`

Public key of repository, sets CVMFS_PUBLIC_KEYS

Default value: ``undef``

##### <a name="cvmfs_keys_dir"></a>`cvmfs_keys_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Directory with public keys for repository, sets CVMFS_KEYS_DIR

Default value: ``undef``

##### <a name="cvmfs_max_ttl"></a>`cvmfs_max_ttl`

Data type: `Optional[Integer]`

Maximum effective TTL in seconds for DNS queries of proxy server names. Sets CVMFS_MAX_TTL

Default value: ``undef``

##### <a name="cvmfs_env_variables"></a>`cvmfs_env_variables`

Data type: `Optional[Hash]`

Sets per repo environments variables for magic links.

Default value: ``undef``

##### <a name="cvmfs_use_geoapi"></a>`cvmfs_use_geoapi`

Data type: `Optional[Stdlib::Yes_no]`

Set CVMFS_MAX_GEOAPI

Default value: ``undef``

##### <a name="mount_method"></a>`mount_method`

Data type: `Enum['autofs','mount','none']`

Should the mount attempt be made with autofs or tranditional fstab mount. Do no use this.

Default value: `$cvmfs::mount_method`

##### <a name="cvmfs_repo_list"></a>`cvmfs_repo_list`

Data type: `Boolean`

If true the repository will added to the list of repositories maintained in `/etc/cvmfs/default.local`

Default value: ``true``

##### <a name="cvmfs_mount_rw"></a>`cvmfs_mount_rw`

Data type: `Optional[Stdlib::Yes_no]`

sets CVMFS_MOUNT_RW

Default value: ``undef``

##### <a name="cvmfs_memcache_size"></a>`cvmfs_memcache_size`

Data type: `Optional[Integer]`

Sets CVMFS_MEMCACHE_SIZE in Megabytes.

Default value: ``undef``

##### <a name="cvmfs_claim_ownership"></a>`cvmfs_claim_ownership`

Data type: `Optional[Stdlib::Yes_no]`

Sets CVMFS_CLAIM_OWNERSHIP.

Default value: ``undef``

##### <a name="cvmfs_uid_map"></a>`cvmfs_uid_map`

Data type: `Optional[Hash[Variant[Integer,String],Integer, 1]]`

Specify a UID map file path for this repository . Sets CVMFS_UID_MAP

Default value: ``undef``

##### <a name="cvmfs_gid_map"></a>`cvmfs_gid_map`

Data type: `Optional[Hash[Variant[Integer,String],Integer, 1]]`

Specify a GID map file path for this repository . Sets CVMFS_GID_MAP

Default value: ``undef``

##### <a name="cvmfs_follow_redirects"></a>`cvmfs_follow_redirects`

Data type: `Optional[Stdlib::Yes_no]`

Sets CVMFS_FOLLOW_REDIRECTS.

Default value: ``undef``

##### <a name="cvmfs_external_fallback_proxy"></a>`cvmfs_external_fallback_proxy`

Data type: `Optional[String]`

Sets CVMFS_EXTERNAL_FALLBACK_PROXY

Default value: ``undef``

##### <a name="cvmfs_external_http_proxy"></a>`cvmfs_external_http_proxy`

Data type: `Optional[String]`

Sets CVMFS_EXTERNAL_HTTP_PROXY

Default value: ``undef``

##### <a name="cvmfs_external_timeout"></a>`cvmfs_external_timeout`

Data type: `Optional[Integer]`

Sets CVMFS_EXTERNAL_TIMEOUT

Default value: ``undef``

##### <a name="cvmfs_external_timeout_direct"></a>`cvmfs_external_timeout_direct`

Data type: `Optional[Integer]`

Sets CVMFS_EXTERNAL_TIMEOUT_DIRECT

Default value: ``undef``

##### <a name="cvmfs_external_url"></a>`cvmfs_external_url`

Data type: `Optional[String]`

Sets CVMFS_EXTERNAL_URL

Default value: ``undef``

##### <a name="cvmfs_repository_tag"></a>`cvmfs_repository_tag`

Data type: `Optional[String[1]]`

Sets CVMFS_REPOSITORY_TAG

Default value: ``undef``

##### <a name="mount_options"></a>`mount_options`

Data type: `String[1]`

Mount options to use for fstab style mounting.

Default value: `'defaults,_netdev,nodev'`

